class {{ python_class_name.pascal_case }}(
{%- if generics_def %}
    Generic[{{ generics_def }}],
    abc.ABC,
):
{%- else -%}
abc.ABC):
{%- endif %}
    @abc.abstractmethod
    def _{{ abstract_method_name.snake_case }}(self{% if arguments %}, {{ arguments }}{% endif %}) -> {{ return_type }}:
        raise NotImplementedError()

